This is a PCB that uses AC power to run a MySensors node inside a wall socket. The main goal is to have a MySensors node with I/O to be able to build your own node with your own sensors inside a normal (European) wall socket. It comes with PCB and a 3d box for protection and safety. 

** Current Status and revision

Rev 4.1 - Testing**


####  Rev 4.1 (Testing!)
- Complete redesign of traces to improve size and stability.
- Nrf24l01+ now on the bottom side to make more room (with hope not RF disturbace from HLK or AC traces).
- Added silkmask with AC-DC seperation (Rev 4.1 > 5mm)
- AC clearance 2.5mm minimum
- Changed one AC trace from botton to top to increace creepage and changed milling
- MysX 2.3 + Analog IO	
- Safety recommendations: This PCB meets the criteria of pollution level II (2,5mm (Basic) AC seperation and 5mm (Reinforced) AC-DC sepertion) and can be used "where only non-conductive contamination occurs. However, occasional temporary conductivity must be expected as a result of moisture condensation." Always use a sealed case to avoid contamination. Always read disclaimer.txt before using this PCB.

**- Found that the silkscreen on the 18B20 and LE33 is backwards! Doublecheck how you solder them! (its offcourse depending if you have the component on bottom or top) Doublecheck these components and dont solder according to silkmask!**


#### Rev 3.1 (OK)

- Larger AC and DC separation (<3.3mm, meaning you can only use it inside Pollution lev I)

- Larger creepage/clearance between AC circuit (Minimum 2.5mm on AC side, allowed to use in Pollution lev II)

- Safety recommendations: Always use this revision inside a sealed case or in an environment where contamination or moisture condensation not occurs.

- Added label with license on board.

- Moved voltage regulator to increase distance to AC side

- Removed high voltage on silk screen

- Added holes between AC ciriut to decrease creepage

- Added lines on silkscreen to mark AC and DC gap.

_For rev history, see Changes.txt_

_Note when buying through openhardware.io may say another rev. This is only revision for manufacturer, not current PCB revision. I always update PCB gerber files for sale first on openhardware.io_

### **Why??**

I designed this project for the main purpose of safely powering a node from a AC source. Battery operations and 5v phone chargers in all its glory but I needed a node small enough to put inside a wall-socket, adaptable/dynamic and AC powered. 

We have AC mains running everywhere in our houses today and this project aims for converting AC to 5vDC with safety as priority #1. 

#### Aim of this project

- Convert 240v/120v AC to 5v DC (using HLK-PM01)

- Make it safe!

- Fit inside standard [appliance box](http://www.elko.se/getfile.php/produkter/img/3/3/4944/Foto4944.jpg) / in wall

- Run MySensors node (Arduino Pro Mini, NRF24L01+, MysX Gpio for sensors)

### **How??**

By using this you have everything you need for a AC powered MySensors node. With MysX connector you have plenty of options both digital and analog input/outputs for you sensors. For the AC power there are both a temperature fuse, a normal fuse, and a varistor to protect your node.

I wanted the node to be dynamic (no sensor specific) - and therefore the MysX connector. Now you can add any sensor you like to the connector. Also, while at it - why not add a relay. Since I'm going to use this around AC i might also be able to switch it in the same time.

Follow this thread for latest info: https://forum.mysensors.org/topic/2488/in-wall-pcb-ac-to-dc-5v and https://forum.mysensors.org/topic/2783/in-wall-ac-dc-pcb-for-mysensors

Build instructions coming soon, see BOM for more info.

### **What??**

**Power **- Using the HLK-PM01 converting AC 240/120v to 5v dc and running the MySensors node. The input is protected with a fuse, temp fuse and varistor ([read this discussion](http://forum.mysensors.org/topic/1607/safe-in-wall-ac-to-dc-transformers)).

**MySensors **- A Arduino Pro Mini and a Nrf24l01+ SMD Radio with all the normal components.

**I/O** - MysX 2.3

**3d-box** - A part of safety, attached is a .stl file with a case for 3d printing. This can be printed in your 3d printer or sent to a 3d-hub. (Coming soon!)

### Safety

Safety is one of the most important aspects of this project! Se more here: https://forum.mysensors.org/topic/4175/clearance-creepage-and-other-safety-aspects-in-mysensors-pcbs. _All revisions from and below 3.1 does not follow all this rules due to space and other limitations. It is highly recommended to use this inside a sealed box and never in a environment where pollution or condensation occurs._

Text below is written for the latest posted revision. For older revisions, please see changes.txt

##### AC-DC Separation
My thoughts has been to separate AC (primary) and DC (secondary) sides completely. At this point this separation is to small and it is only recommended to use (for all revisions below 3.2) it in pollution level I only _(No contamination or only dry, non-conductive contamination occurs. The contamination has no influence.)_

The HLK-PM01 has been discussed in many threads here and are transformer based so it should be safe. More about it [here ](http://lygte-info.dk/review/Power%20Mains%20to%205V%200.6A%20Hi-Link%20HLK-PM01%20UK.html)and [here](https://skippy.org.uk/quick-look-at-the-hlk-pm01/).  

Note: there has recently (Sept 16) been some [fake/pirated HLK components](https://forum.mysensors.org/topic/1607/safe-in-wall-ac-to-dc-transformers/356)! Warning!

##### AC high voltage trace creepage

As for the separation within the AC traces I have tried to use 3mm creepage and clearance but this turned out to be to hard. This PCB has a creepage distance on the AC side of 2.5mm. This means if you are using 240v you can put it in pollution level II Sames as above, don't use it outdoors and put it in a case.

##### Temperature in closed compartment
![Temp](https://www.openhardware.io//uploads/5693e2ffaab2635a049184d5/image/rename.jpg "enter image title here")

### Disclaimer

If you order or use this you agree to and understand that the author is not liable for any injury or damage howsoever caused and that you use this PCB at your own risk. This is DIY and the author has not made any professional test. This product has not been marked with any certification marks and cant be guaranteed to compliance with any standards. 

### **Cost**?
Total cost for one node is about US$8 where the Arduino and HLK-pm01 is about US$6,5 (See BOM).

### **Bonus**

You can actually cut/split the PCB between AC and DC side and get a normal 5v Mysensors node where you can attach sensors to MysX connector.

##### Links

- http://forum.mysensors.org/topic/1607/safe-in-wall-ac-to-dc-transformers

- http://forum.mysensors.org/topic/1540/110v-230v-ac-to-mysensors-pcb-board

- [Performance test and review of mains to 5V 0.6A Hi-Link HLK-PM01](http://lygte-info.dk/review/Power%20Mains%20to%205V%200.6A%20Hi-Link%20HLK-PM01%20UK.html)

- https://skippy.org.uk/quick-look-at-the-hlk-pm01/

- https://www.ieee.li/pdf/essay/safety_considerations_in_power_supply_design.pdf

### Questions needing answers

- Reliability, when will it fail? (compared to a commercial product?)
- How will it fail? What is it weakest point?
- Will my safety components be enough and prevail damage... ?
- What will happen when it fails?

### **I want it!**
- Order 10pcs: [openhardware.io](https://www.openhardware.io/order/13/PCB10X) (Recommended!) and support me and MySensors!
- Download from this page to get Eagles and Gerber files. Note that the gerber files are run with Itead cam job.
- If you want a faster shipping time or less pieces you can buy them from me via [Ebay](http://www.ebay.com/itm/222572520933?).